==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicMapImageryDescription_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
import { SeriesViewerDescription } from "./SeriesViewerDescription";
/**
 * @hidden
 */
var GeographicMapImageryDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapImageryDescription, _super);
    function GeographicMapImageryDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.f = null;
        _this.r = null;
        _this.j = false;
        _this.s = null;
        _this.l = 0;
        _this.q = null;
        _this.p = null;
        _this.n = null;
        _this.o = null;
        return _this;
    }
    GeographicMapImageryDescription.prototype.get_type = function () {
        return "GeographicMapImagery";
    };
    Object.defineProperty(GeographicMapImageryDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "windowRect", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("WindowRect");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "geographicMap", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("GeographicMap");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "referer", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.e("Referer");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "isHorizontalWrappingEnabled", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("IsHorizontalWrappingEnabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "userAgent", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.e("UserAgent");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "opacity", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("Opacity");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "imageTilesReadyRef", {
        get: function () {
            return this.q;
        },
        set: function (a) {
            this.q = a;
            this.e("ImageTilesReadyRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "imagesChangedRef", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.e("ImagesChangedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "cancellingImageRef", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("CancellingImageRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "downloadingImageRef", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.e("DownloadingImageRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicMapImageryDescription.$t = markType(GeographicMapImageryDescription, 'GeographicMapImageryDescription', Description.$);
    return GeographicMapImageryDescription;
}(Description));
export { GeographicMapImageryDescription };
/**
 * @hidden
 */
var GeographicMapDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapDescription, _super);
    function GeographicMapDescription() {
        var _this = _super.call(this) || this;
        _this.hc = false;
        _this.ho = null;
        _this.g9 = false;
        _this.hl = null;
        _this.hb = false;
        _this.ha = false;
        _this.g6 = null;
        _this.g5 = null;
        _this.g3 = null;
        _this.hi = 0;
        _this.hh = 0;
        _this.hn = null;
        _this.hp = null;
        _this.hm = null;
        return _this;
    }
    GeographicMapDescription.prototype.get_type = function () {
        return "GeographicMap";
    };
    Object.defineProperty(GeographicMapDescription.prototype, "zoomable", {
        get: function () {
            return this.hc;
        },
        set: function (a) {
            this.hc = a;
            this.e("Zoomable");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "resizeBehavior", {
        get: function () {
            return this.ho;
        },
        set: function (a) {
            this.ho = a;
            this.e("ResizeBehavior");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "isHorizontalWrappingEnabled", {
        get: function () {
            return this.g9;
        },
        set: function (a) {
            this.g9 = a;
            this.e("IsHorizontalWrappingEnabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "backgroundTilingMode", {
        get: function () {
            return this.hl;
        },
        set: function (a) {
            this.hl = a;
            this.e("BackgroundTilingMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "useWorldRectForZoomBounds", {
        get: function () {
            return this.hb;
        },
        set: function (a) {
            this.hb = a;
            this.e("UseWorldRectForZoomBounds");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "suppressZoomResetOnWorldRectChange", {
        get: function () {
            return this.ha;
        },
        set: function (a) {
            this.ha = a;
            this.e("SuppressZoomResetOnWorldRectChange");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "worldRect", {
        get: function () {
            return this.g6;
        },
        set: function (a) {
            this.g6 = a;
            this.e("WorldRect");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "actualWorldRect", {
        get: function () {
            return this.g5;
        },
        set: function (a) {
            this.g5 = a;
            this.e("ActualWorldRect");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "backgroundContent", {
        get: function () {
            return this.g3;
        },
        set: function (a) {
            this.g3 = a;
            this.e("BackgroundContent");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "windowScale", {
        get: function () {
            return this.hi;
        },
        set: function (a) {
            this.hi = a;
            this.e("WindowScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "actualWindowScale", {
        get: function () {
            return this.hh;
        },
        set: function (a) {
            this.hh = a;
            this.e("ActualWindowScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "imageTilesReadyRef", {
        get: function () {
            return this.hn;
        },
        set: function (a) {
            this.hn = a;
            this.e("ImageTilesReadyRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "width", {
        get: function () {
            return this.hp;
        },
        set: function (a) {
            this.hp = a;
            this.e("Width");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "height", {
        get: function () {
            return this.hm;
        },
        set: function (a) {
            this.hm = a;
            this.e("Height");
        },
        enumerable: false,
        configurable: true
    });
    GeographicMapDescription.$t = markType(GeographicMapDescription, 'GeographicMapDescription', SeriesViewerDescription.$);
    return GeographicMapDescription;
}(SeriesViewerDescription));
export { GeographicMapDescription };

==> igniteui-react-core-18.7.4.tgz: package/esm5/lib/GeographicMapImageryDescription_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
import { SeriesViewerDescription } from "./SeriesViewerDescription";
/**
 * @hidden
 */
var GeographicMapImageryDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapImageryDescription, _super);
    function GeographicMapImageryDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.h = null;
        _this.t = null;
        _this.l = false;
        _this.u = null;
        _this.n = 0;
        _this.s = null;
        _this.r = null;
        _this.p = null;
        _this.q = null;
        return _this;
    }
    GeographicMapImageryDescription.prototype.get_type = function () {
        return "GeographicMapImagery";
    };
    Object.defineProperty(GeographicMapImageryDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "windowRect", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("WindowRect");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "geographicMap", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("GeographicMap");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "referer", {
        get: function () {
            return this.t;
        },
        set: function (a) {
            this.t = a;
            this.g("Referer");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "isHorizontalWrappingEnabled", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("IsHorizontalWrappingEnabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "userAgent", {
        get: function () {
            return this.u;
        },
        set: function (a) {
            this.u = a;
            this.g("UserAgent");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "opacity", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.g("Opacity");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "imageTilesReadyRef", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.g("ImageTilesReadyRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "imagesChangedRef", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.g("ImagesChangedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "cancellingImageRef", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("CancellingImageRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapImageryDescription.prototype, "downloadingImageRef", {
        get: function () {
            return this.q;
        },
        set: function (a) {
            this.q = a;
            this.g("DownloadingImageRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicMapImageryDescription.$t = markType(GeographicMapImageryDescription, 'GeographicMapImageryDescription', Description.$);
    return GeographicMapImageryDescription;
}(Description));
export { GeographicMapImageryDescription };
/**
 * @hidden
 */
var GeographicMapDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapDescription, _super);
    function GeographicMapDescription() {
        var _this = _super.call(this) || this;
        _this.h8 = false;
        _this.il = null;
        _this.h5 = false;
        _this.ii = null;
        _this.h7 = false;
        _this.h6 = false;
        _this.h2 = null;
        _this.h1 = null;
        _this.hz = null;
        _this.ie = 0;
        _this.id = 0;
        _this.ik = null;
        _this.im = null;
        _this.ij = null;
        return _this;
    }
    GeographicMapDescription.prototype.get_type = function () {
        return "GeographicMap";
    };
    Object.defineProperty(GeographicMapDescription.prototype, "zoomable", {
        get: function () {
            return this.h8;
        },
        set: function (a) {
            this.h8 = a;
            this.g("Zoomable");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "resizeBehavior", {
        get: function () {
            return this.il;
        },
        set: function (a) {
            this.il = a;
            this.g("ResizeBehavior");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "isHorizontalWrappingEnabled", {
        get: function () {
            return this.h5;
        },
        set: function (a) {
            this.h5 = a;
            this.g("IsHorizontalWrappingEnabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "backgroundTilingMode", {
        get: function () {
            return this.ii;
        },
        set: function (a) {
            this.ii = a;
            this.g("BackgroundTilingMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "useWorldRectForZoomBounds", {
        get: function () {
            return this.h7;
        },
        set: function (a) {
            this.h7 = a;
            this.g("UseWorldRectForZoomBounds");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "suppressZoomResetOnWorldRectChange", {
        get: function () {
            return this.h6;
        },
        set: function (a) {
            this.h6 = a;
            this.g("SuppressZoomResetOnWorldRectChange");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "worldRect", {
        get: function () {
            return this.h2;
        },
        set: function (a) {
            this.h2 = a;
            this.g("WorldRect");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "actualWorldRect", {
        get: function () {
            return this.h1;
        },
        set: function (a) {
            this.h1 = a;
            this.g("ActualWorldRect");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "backgroundContent", {
        get: function () {
            return this.hz;
        },
        set: function (a) {
            this.hz = a;
            this.g("BackgroundContent");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "windowScale", {
        get: function () {
            return this.ie;
        },
        set: function (a) {
            this.ie = a;
            this.g("WindowScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "actualWindowScale", {
        get: function () {
            return this.id;
        },
        set: function (a) {
            this.id = a;
            this.g("ActualWindowScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "imageTilesReadyRef", {
        get: function () {
            return this.ik;
        },
        set: function (a) {
            this.ik = a;
            this.g("ImageTilesReadyRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "width", {
        get: function () {
            return this.im;
        },
        set: function (a) {
            this.im = a;
            this.g("Width");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicMapDescription.prototype, "height", {
        get: function () {
            return this.ij;
        },
        set: function (a) {
            this.ij = a;
            this.g("Height");
        },
        enumerable: false,
        configurable: true
    });
    GeographicMapDescription.$t = markType(GeographicMapDescription, 'GeographicMapDescription', SeriesViewerDescription.$);
    return GeographicMapDescription;
}(SeriesViewerDescription));
export { GeographicMapDescription };
